"boa.plot.title" <-
function(text)
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
{
   mtext(text, line = 1, outer = TRUE, cex = 2)
   invisible()
}
